@@ -1,5 +1,5 @@
 #define USING_R 1
-/*  Copyright by Roger Bivand (C) 2005  */
+/*  Copyright by Roger Bivand (C) 2005-2009  */
 
 #include "sp.h"
 
@@ -28,6 +28,23 @@ void sp_dists(double *u, double *v, double *uout, double *vout,
 	}
 }
 
+void sp_lengths(double *u, double *v, int *n, double *lengths, int *lonlat)
+{
+	int N = *n, j;
+	double gc[1];
+        if (N < 2) error("N less than 2");
+		
+	if (lonlat[0] == 0) {
+		for (j=0; j<(N-1); j++) 
+			lengths[j] = pythag((u[j]-u[(j+1)]), (v[j]-v[(j+1)]));
+	} else {
+		for (j=0; j<(N-1); j++) {
+			sp_gcdist(u+j, u+(j+1), v+j, v+(j+1), gc);
+		    	lengths[j] = gc[0];
+		}
+	}
+
+}
 
 /* http://home.att.net/~srschmitt/script_greatcircle.html */
 
